==> Bencher-Scenarios-DataComparisonModules-0.001.tar.gz: Bencher-Scenarios-DataComparisonModules-0.001/lib/Bencher/Scenarios/DataComparisonModules.pm <==
package Bencher::Scenarios::DataComparisonModules;

our $DATE = '2018-08-12'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: A collection of bencher scenarios to benchmark data structure comparison modules

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::DataComparisonModules - A collection of bencher scenarios to benchmark data structure comparison modules

=head1 VERSION

This document describes version 0.001 of Bencher::Scenarios::DataComparisonModules (from Perl distribution Bencher-Scenarios-DataComparisonModules), released on 2018-08-12.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::DataComparisonModules::Compare>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-DataComparisonModules>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-DataComparisonModues>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-DataComparisonModules>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Bencher-Scenarios-DataComparisonModules-0.002.tar.gz: Bencher-Scenarios-DataComparisonModules-0.002/lib/Bencher/Scenarios/DataComparisonModules.pm <==
package Bencher::Scenarios::DataComparisonModules;

our $DATE = '2018-08-12'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: A collection of bencher scenarios to benchmark data structure comparison modules

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::DataComparisonModules - A collection of bencher scenarios to benchmark data structure comparison modules

=head1 VERSION

This document describes version 0.002 of Bencher::Scenarios::DataComparisonModules (from Perl distribution Bencher-Scenarios-DataComparisonModules), released on 2018-08-12.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::DataComparisonModules::Compare>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-DataComparisonModules>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-DataComparisonModules>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-DataComparisonModules>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
